
# Enum: optimizer_enum


Optimizers that can be implemented in the neural network.

URI: [https://w3id.org/neat/optimizer_enum](https://w3id.org/neat/optimizer_enum)


## Other properties

|  |  |  |
| --- | --- | --- |

## Permissible Values

| Text | Description | Meaning | Other Information |
| :--- | :---: | :---: | ---: |
| adagrad | Optimizer that implements the Adagrad algorithm. |  |  |
| adam | Optimizer that implements the Adam algorithm. |  |  |
| adamax | Optimizer that implements the Adamax algorithm. |  |  |
| nadam | Optimizer that implements the NAdam algorithm. |  |  |
| sgd | Stochastic gradient descent (with momentum) optimizer. |  |  |

